@@ -23,7 +23,7 @@ class MyView (View):
        pressed, the counter will be incremented."""
 
     def __init__(self, ctrl):
-        View.__init__(self, ctrl, 'gtkmvc-example.glade')
+        View.__init__(self, ctrl, 'pygtkmvc-example.glade')
         return
 
     pass # end of class
